function W = BuildDirectedKNNGraph(S,k)
% creates incidence matrix of a directed kNN graph from similarity matrix 
% Wij is non-zero if node j is among k nearest neighbours of node i, the
% matrix is not symmetric

% Input: 
% S = similarity matrix, square, symmetrix, without negative entries
% k = number of neighbours

% correctness test
if (size(S,1) ~= size(S,2))
  error('Matrix is not square!')
end

n = size(S,1);

% removing self-loops
for it=1:n
  S(it,it) = 0; 
end


% create similarity matrix
W = S; 

for it = 1:n
  % sort points according to similarities
  [sorted_row,order] = sort(S(it,:), 'descend'); 
  % set the entries in W to zero for the points which are not among k first
  % points
  W(it, order(k+1:end)) = 0;
end

  
